@@ -5,10 +5,13 @@ import uuid
 
 from stix2.canonicalization.Canonicalize import canonicalize
 
-from pycti.entities import LOGGER
-
 
 class AttackPattern:
+    """Main AttackPattern class for OpenCTI
+
+    :param opencti: instance of :py:class:`~pycti.api.opencti_api_client.OpenCTIApiClient`
+    """
+
     def __init__(self, opencti):
         self.opencti = opencti
         self.properties = """
@@ -19,6 +22,14 @@ class AttackPattern:
             spec_version
             created_at
             updated_at
+            status {
+                id
+                template {
+                  id
+                  name
+                  color
+                }
+            }
             createdBy {
                 ... on Identity {
                     id
@@ -35,13 +46,9 @@ class AttackPattern:
                     created
                     modified
                     objectLabel {
-                        edges {
-                            node {
-                                id
-                                value
-                                color
-                            }
-                        }
+                        id
+                        value
+                        color
                     }
                 }
                 ... on Organization {
@@ -54,28 +61,120 @@ class AttackPattern:
                 }
             }
             objectMarking {
+                id
+                standard_id
+                entity_type
+                definition_type
+                definition
+                created
+                modified
+                x_opencti_order
+                x_opencti_color
+            }
+            objectLabel {
+                id
+                value
+                color
+            }
+            externalReferences {
                 edges {
                     node {
                         id
                         standard_id
                         entity_type
-                        definition_type
-                        definition
+                        source_name
+                        description
+                        url
+                        hash
+                        external_id
                         created
                         modified
-                        x_opencti_order
-                        x_opencti_color
                     }
                 }
             }
-            objectLabel {
-                edges {
-                    node {
+            revoked
+            confidence
+            created
+            modified
+            name
+            description
+            aliases
+            x_mitre_platforms
+            x_mitre_permissions_required
+            x_mitre_detection
+            x_mitre_id
+            killChainPhases {
+              id
+              standard_id
+              entity_type
+              kill_chain_name
+              phase_name
+              x_opencti_order
+              created
+              modified
+            }
+        """
+        self.properties_with_files = """
+            id
+            standard_id
+            entity_type
+            parent_types
+            spec_version
+            created_at
+            updated_at
+            status {
+                id
+                template {
+                  id
+                  name
+                  color
+                }
+            }
+            createdBy {
+                ... on Identity {
+                    id
+                    standard_id
+                    entity_type
+                    parent_types
+                    spec_version
+                    identity_class
+                    name
+                    description
+                    roles
+                    contact_information
+                    x_opencti_aliases
+                    created
+                    modified
+                    objectLabel {
                         id
                         value
                         color
                     }
                 }
+                ... on Organization {
+                    x_opencti_organization_type
+                    x_opencti_reliability
+                }
+                ... on Individual {
+                    x_opencti_firstname
+                    x_opencti_lastname
+                }
+            }
+            objectMarking {
+                id
+                standard_id
+                entity_type
+                definition_type
+                definition
+                created
+                modified
+                x_opencti_order
+                x_opencti_color
+            }
+            objectLabel {
+                id
+                value
+                color
             }
             externalReferences {
                 edges {
@@ -118,18 +217,14 @@ class AttackPattern:
             x_mitre_detection
             x_mitre_id
             killChainPhases {
-                edges {
-                    node {
-                        id
-                        standard_id
-                        entity_type
-                        kill_chain_name
-                        phase_name
-                        x_opencti_order
-                        created
-                        modified
-                    }
-                }
+              id
+              standard_id
+              entity_type
+              kill_chain_name
+              phase_name
+              x_opencti_order
+              created
+              modified
             }
             importFiles {
                 edges {
@@ -148,26 +243,51 @@ class AttackPattern:
 
     @staticmethod
     def generate_id(name, x_mitre_id=None):
-        name = name.lower().strip()
+        """Generate a STIX ID for an Attack Pattern.
+
+        :param name: The name of the attack pattern
+        :type name: str
+        :param x_mitre_id: Optional MITRE ATT&CK ID
+        :type x_mitre_id: str or None
+        :return: STIX ID for the attack pattern
+        :rtype: str
+        """
         if x_mitre_id is not None:
-            data = {"x_mitre_id": x_mitre_id}
+            data = {"x_mitre_id": x_mitre_id.strip()}
         else:
-            data = {"name": name}
+            data = {"name": name.lower().strip()}
         data = canonicalize(data, utf8=False)
         id = str(uuid.uuid5(uuid.UUID("00abedb4-aa42-466c-9c01-fed23315a9b7"), data))
         return "attack-pattern--" + id
 
-    """
-        List Attack-Pattern objects
+    @staticmethod
+    def generate_id_from_data(data):
+        """Generate a STIX ID from attack pattern data.
+
+        :param data: Dictionary containing 'name' and optionally 'x_mitre_id' keys
+        :type data: dict
+        :return: STIX ID for the attack pattern
+        :rtype: str
+        """
+        external_id = data.get("x_mitre_id") or data.get("x_opencti_external_id")
+        return AttackPattern.generate_id(data.get("name"), external_id)
+
+    def list(self, **kwargs):
+        """List Attack Pattern objects.
 
         :param filters: the filters to apply
         :param search: the search keyword
         :param first: return the first n rows from the after ID (or the beginning if not set)
         :param after: ID of the first row for pagination
-        :return List of Attack-Pattern objects
-    """
-
-    def list(self, **kwargs):
+        :param orderBy: field to order results by
+        :param orderMode: ordering mode (asc/desc)
+        :param customAttributes: custom attributes to return
+        :param getAll: whether to retrieve all results
+        :param withPagination: whether to include pagination info
+        :param withFiles: whether to include files
+        :return: List of Attack Pattern objects
+        :rtype: list
+        """
         filters = kwargs.get("filters", None)
         search = kwargs.get("search", None)
         first = kwargs.get("first", 500)
@@ -177,18 +297,23 @@ class AttackPattern:
         custom_attributes = kwargs.get("customAttributes", None)
         get_all = kwargs.get("getAll", False)
         with_pagination = kwargs.get("withPagination", False)
-        if get_all:
-            first = 500
+        with_files = kwargs.get("withFiles", False)
 
-        LOGGER.info("Listing Attack-Patterns with filters %s.", json.dumps(filters))
+        self.opencti.app_logger.info(
+            "Listing Attack-Patterns with filters", {"filters": json.dumps(filters)}
+        )
         query = (
             """
-            query AttackPatterns($filters: [AttackPatternsFiltering], $search: String, $first: Int, $after: ID, $orderBy: AttackPatternsOrdering, $orderMode: OrderingMode) {
+            query AttackPatterns($filters: FilterGroup, $search: String, $first: Int, $after: ID, $orderBy: AttackPatternsOrdering, $orderMode: OrderingMode) {
                 attackPatterns(filters: $filters, search: $search, first: $first, after: $after, orderBy: $orderBy, orderMode: $orderMode) {
                     edges {
                         node {
                             """
-            + (custom_attributes if custom_attributes is not None else self.properties)
+            + (
+                custom_attributes
+                if custom_attributes is not None
+                else (self.properties_with_files if with_files else self.properties)
+            )
             + """
                         }
                     }
@@ -220,7 +345,9 @@ class AttackPattern:
             final_data = final_data + data
             while result["data"]["attackPatterns"]["pageInfo"]["hasNextPage"]:
                 after = result["data"]["attackPatterns"]["pageInfo"]["endCursor"]
-                LOGGER.info("Listing Attack-Patterns after " + after)
+                self.opencti.app_logger.info(
+                    "Listing Attack-Patterns", {"after": after}
+                )
                 result = self.opencti.query(
                     query,
                     {
@@ -252,8 +379,9 @@ class AttackPattern:
         id = kwargs.get("id", None)
         filters = kwargs.get("filters", None)
         custom_attributes = kwargs.get("customAttributes", None)
+        with_files = kwargs.get("withFiles", False)
         if id is not None:
-            LOGGER.info("Reading Attack-Pattern {%s}.", id)
+            self.opencti.app_logger.info("Reading Attack-Pattern", {"id": id})
             query = (
                 """
                 query AttackPattern($id: String!) {
@@ -262,7 +390,7 @@ class AttackPattern:
                 + (
                     custom_attributes
                     if custom_attributes is not None
-                    else self.properties
+                    else (self.properties_with_files if with_files else self.properties)
                 )
                 + """
                     }
@@ -278,7 +406,9 @@ class AttackPattern:
             else:
                 return None
         else:
-            LOGGER.error("[opencti_attack_pattern] Missing parameters: id or filters")
+            self.opencti.app_logger.error(
+                "[opencti_attack_pattern] Missing parameters: id or filters"
+            )
             return None
 
     """
@@ -309,12 +439,13 @@ class AttackPattern:
         kill_chain_phases = kwargs.get("killChainPhases", None)
         x_opencti_stix_ids = kwargs.get("x_opencti_stix_ids", None)
         granted_refs = kwargs.get("objectOrganization", None)
+        x_opencti_workflow_id = kwargs.get("x_opencti_workflow_id", None)
         update = kwargs.get("update", False)
 
         if name is not None:
-            LOGGER.info("Creating Attack-Pattern {%s}.", name)
+            self.opencti.app_logger.info("Creating Attack-Pattern", {"name": name})
             query = """
-                mutation AttackPatternAdd($input: AttackPatternAddInput) {
+                mutation AttackPatternAdd($input: AttackPatternAddInput!) {
                     attackPatternAdd(input: $input) {
                         id
                         standard_id
@@ -347,6 +478,7 @@ class AttackPattern:
                         "x_mitre_id": x_mitre_id,
                         "killChainPhases": kill_chain_phases,
                         "x_opencti_stix_ids": x_opencti_stix_ids,
+                        "x_opencti_workflow_id": x_opencti_workflow_id,
                         "update": update,
                     }
                 },
@@ -355,7 +487,7 @@ class AttackPattern:
                 result["data"]["attackPatternAdd"]
             )
         else:
-            LOGGER.error(
+            self.opencti.app_logger.error(
                 "[opencti_attack_pattern] Missing parameters: name and description"
             )
 
@@ -384,13 +516,7 @@ class AttackPattern:
                 )
             elif "external_references" in stix_object:
                 for external_reference in stix_object["external_references"]:
-                    if (
-                        external_reference["source_name"] == "mitre-attack"
-                        or external_reference["source_name"] == "mitre-pre-attack"
-                        or external_reference["source_name"] == "mitre-mobile-attack"
-                        or external_reference["source_name"] == "mitre-ics-attack"
-                        or external_reference["source_name"] == "amitt-attack"
-                    ):
+                    if external_reference["source_name"].startswith("mitre-"):
                         x_mitre_id = (
                             external_reference["external_id"]
                             if "external_id" in external_reference
@@ -406,90 +532,119 @@ class AttackPattern:
                     else 0
                 )
             if "x_mitre_platforms" not in stix_object:
-                stix_object[
-                    "x_mitre_platforms"
-                ] = self.opencti.get_attribute_in_mitre_extension(
-                    "platforms", stix_object
+                stix_object["x_mitre_platforms"] = (
+                    self.opencti.get_attribute_in_mitre_extension(
+                        "platforms", stix_object
+                    )
                 )
             if "x_mitre_permissions_required" not in stix_object:
-                stix_object[
-                    "x_mitre_permissions_required"
-                ] = self.opencti.get_attribute_in_mitre_extension(
-                    "permissions_required", stix_object
+                stix_object["x_mitre_permissions_required"] = (
+                    self.opencti.get_attribute_in_mitre_extension(
+                        "permissions_required", stix_object
+                    )
                 )
             if "x_mitre_detection" not in stix_object:
-                stix_object[
-                    "x_mitre_detection"
-                ] = self.opencti.get_attribute_in_mitre_extension(
-                    "detection", stix_object
+                stix_object["x_mitre_detection"] = (
+                    self.opencti.get_attribute_in_mitre_extension(
+                        "detection", stix_object
+                    )
                 )
             if "x_opencti_stix_ids" not in stix_object:
-                stix_object[
-                    "x_opencti_stix_ids"
-                ] = self.opencti.get_attribute_in_extension("stix_ids", stix_object)
-            if "granted_refs" not in stix_object:
-                stix_object["granted_refs"] = self.opencti.get_attribute_in_extension(
-                    "granted_refs", stix_object
+                stix_object["x_opencti_stix_ids"] = (
+                    self.opencti.get_attribute_in_extension("stix_ids", stix_object)
+                )
+            if "x_opencti_granted_refs" not in stix_object:
+                stix_object["x_opencti_granted_refs"] = (
+                    self.opencti.get_attribute_in_extension("granted_refs", stix_object)
+                )
+            if "x_opencti_workflow_id" not in stix_object:
+                stix_object["x_opencti_workflow_id"] = (
+                    self.opencti.get_attribute_in_extension("workflow_id", stix_object)
                 )
 
             return self.create(
                 stix_id=stix_object["id"],
-                createdBy=extras["created_by_id"]
-                if "created_by_id" in extras
-                else None,
-                objectMarking=extras["object_marking_ids"]
-                if "object_marking_ids" in extras
-                else None,
-                objectLabel=extras["object_label_ids"]
-                if "object_label_ids" in extras
-                else [],
-                externalReferences=extras["external_references_ids"]
-                if "external_references_ids" in extras
-                else [],
+                createdBy=(
+                    extras["created_by_id"] if "created_by_id" in extras else None
+                ),
+                objectMarking=(
+                    extras["object_marking_ids"]
+                    if "object_marking_ids" in extras
+                    else None
+                ),
+                objectLabel=(
+                    extras["object_label_ids"] if "object_label_ids" in extras else None
+                ),
+                externalReferences=(
+                    extras["external_references_ids"]
+                    if "external_references_ids" in extras
+                    else None
+                ),
                 revoked=stix_object["revoked"] if "revoked" in stix_object else None,
-                confidence=stix_object["confidence"]
-                if "confidence" in stix_object
-                else None,
+                confidence=(
+                    stix_object["confidence"] if "confidence" in stix_object else None
+                ),
                 lang=stix_object["lang"] if "lang" in stix_object else None,
                 created=stix_object["created"] if "created" in stix_object else None,
                 modified=stix_object["modified"] if "modified" in stix_object else None,
                 name=stix_object["name"],
-                description=self.opencti.stix2.convert_markdown(
-                    stix_object["description"]
-                )
-                if "description" in stix_object
-                else "",
+                description=(
+                    self.opencti.stix2.convert_markdown(stix_object["description"])
+                    if "description" in stix_object
+                    else None
+                ),
                 aliases=self.opencti.stix2.pick_aliases(stix_object),
-                x_mitre_platforms=stix_object["x_mitre_platforms"]
-                if "x_mitre_platforms" in stix_object
-                else stix_object["x_amitt_platforms"]
-                if "x_amitt_platforms" in stix_object
-                else None,
-                x_mitre_permissions_required=stix_object["x_mitre_permissions_required"]
-                if "x_mitre_permissions_required" in stix_object
-                else None,
-                x_mitre_detection=stix_object["x_mitre_detection"]
-                if "x_mitre_detection" in stix_object
-                else None,
+                x_mitre_platforms=(
+                    stix_object["x_mitre_platforms"]
+                    if "x_mitre_platforms" in stix_object
+                    else (
+                        stix_object["x_amitt_platforms"]
+                        if "x_amitt_platforms" in stix_object
+                        else None
+                    )
+                ),
+                x_mitre_permissions_required=(
+                    stix_object["x_mitre_permissions_required"]
+                    if "x_mitre_permissions_required" in stix_object
+                    else None
+                ),
+                x_mitre_detection=(
+                    stix_object["x_mitre_detection"]
+                    if "x_mitre_detection" in stix_object
+                    else None
+                ),
                 x_mitre_id=x_mitre_id,
-                killChainPhases=extras["kill_chain_phases_ids"]
-                if "kill_chain_phases_ids" in extras
-                else None,
-                x_opencti_stix_ids=stix_object["x_opencti_stix_ids"]
-                if "x_opencti_stix_ids" in stix_object
-                else None,
-                objectOrganization=stix_object["granted_refs"]
-                if "granted_refs" in stix_object
-                else None,
+                killChainPhases=(
+                    extras["kill_chain_phases_ids"]
+                    if "kill_chain_phases_ids" in extras
+                    else None
+                ),
+                x_opencti_stix_ids=(
+                    stix_object["x_opencti_stix_ids"]
+                    if "x_opencti_stix_ids" in stix_object
+                    else None
+                ),
+                objectOrganization=(
+                    stix_object["x_opencti_granted_refs"]
+                    if "x_opencti_granted_refs" in stix_object
+                    else None
+                ),
+                x_opencti_workflow_id=(
+                    stix_object["x_opencti_workflow_id"]
+                    if "x_opencti_workflow_id" in stix_object
+                    else None
+                ),
                 update=update,
             )
         else:
-            LOGGER.error("[opencti_attack_pattern] Missing parameters: stixObject")
+            self.opencti.app_logger.error(
+                "[opencti_attack_pattern] Missing parameters: stixObject"
+            )
 
     def delete(self, **kwargs):
         id = kwargs.get("id", None)
         if id is not None:
-            LOGGER.info("Deleting Attack Pattern {%s}.", id)
+            self.opencti.app_logger.info("Deleting Attack Pattern", {"id": id})
             query = """
                  mutation AttackPatternEdit($id: ID!) {
                      attackPatternEdit(id: $id) {
@@ -499,5 +654,5 @@ class AttackPattern:
              """
             self.opencti.query(query, {"id": id})
         else:
-            LOGGER.error("[attack_pattern] Missing parameters: id")
+            self.opencti.app_logger.error("[attack_pattern] Missing parameters: id")
             return None
