@@ -7,6 +7,13 @@ from stix2.canonicalization.Canonicalize import canonicalize
 
 
 class DataComponent:
+    """Main DataComponent class for OpenCTI
+
+    Manages MITRE ATT&CK data components in the OpenCTI platform.
+
+    :param opencti: instance of :py:class:`~pycti.api.opencti_api_client.OpenCTIApiClient`
+    """
+
     def __init__(self, opencti):
         self.opencti = opencti
         self.properties = """
@@ -17,6 +24,14 @@ class DataComponent:
             spec_version
             created_at
             updated_at
+            status {
+                id
+                template {
+                  id
+                  name
+                  color
+                }
+            }
             createdBy {
                 ... on Identity {
                     id
@@ -33,13 +48,9 @@ class DataComponent:
                     created
                     modified
                     objectLabel {
-                        edges {
-                            node {
-                                id
-                                value
-                                color
-                            }
-                        }
+                        id
+                        value
+                        color
                     }
                 }
                 ... on Organization {
@@ -51,29 +62,135 @@ class DataComponent:
                     x_opencti_lastname
                 }
             }
+            objectOrganization {
+                id
+                standard_id
+                name
+            }
             objectMarking {
+                id
+                standard_id
+                entity_type
+                definition_type
+                definition
+                created
+                modified
+                x_opencti_order
+                x_opencti_color
+            }
+            objectLabel {
+                id
+                value
+                color
+            }
+            externalReferences {
                 edges {
                     node {
                         id
                         standard_id
                         entity_type
-                        definition_type
-                        definition
+                        source_name
+                        description
+                        url
+                        hash
+                        external_id
                         created
                         modified
-                        x_opencti_order
-                        x_opencti_color
                     }
                 }
             }
-            objectLabel {
-                edges {
-                    node {
+            revoked
+            confidence
+            created
+            modified
+            name
+            description
+            aliases
+            dataSource {
+                id
+                standard_id
+                entity_type
+                parent_types
+                spec_version
+                created_at
+                updated_at
+                revoked
+                confidence
+                created
+                modified
+                name
+                description
+                aliases
+                x_mitre_platforms
+                collection_layers
+            }
+        """
+        self.properties_with_files = """
+            id
+            standard_id
+            entity_type
+            parent_types
+            spec_version
+            created_at
+            updated_at
+            status {
+                id
+                template {
+                  id
+                  name
+                  color
+                }
+            }
+            createdBy {
+                ... on Identity {
+                    id
+                    standard_id
+                    entity_type
+                    parent_types
+                    spec_version
+                    identity_class
+                    name
+                    description
+                    roles
+                    contact_information
+                    x_opencti_aliases
+                    created
+                    modified
+                    objectLabel {
                         id
                         value
                         color
                     }
                 }
+                ... on Organization {
+                    x_opencti_organization_type
+                    x_opencti_reliability
+                }
+                ... on Individual {
+                    x_opencti_firstname
+                    x_opencti_lastname
+                }
+            }
+            objectOrganization {
+                id
+                standard_id
+                name
+            }
+            objectMarking {
+                id
+                standard_id
+                entity_type
+                definition_type
+                definition
+                created
+                modified
+                x_opencti_order
+                x_opencti_color
+            }
+            objectLabel {
+                id
+                value
+                color
             }
             externalReferences {
                 edges {
@@ -152,6 +269,10 @@ class DataComponent:
         id = str(uuid.uuid5(uuid.UUID("00abedb4-aa42-466c-9c01-fed23315a9b7"), data))
         return "data-component--" + id
 
+    @staticmethod
+    def generate_id_from_data(data):
+        return DataComponent.generate_id(data["name"])
+
     """
         List Data-Component objects
 
@@ -172,21 +293,23 @@ class DataComponent:
         custom_attributes = kwargs.get("customAttributes", None)
         get_all = kwargs.get("getAll", False)
         with_pagination = kwargs.get("withPagination", False)
-        if get_all:
-            first = 500
+        with_files = kwargs.get("withFiles", False)
 
-        self.opencti.log(
-            "info",
-            "Listing Data-Components with filters " + json.dumps(filters) + ".",
+        self.opencti.app_logger.info(
+            "Listing Data-Components with filters", {"filters": json.dumps(filters)}
         )
         query = (
             """
-            query DataComponents($filters: [DataComponentsFiltering!], $search: String, $first: Int, $after: ID, $orderBy: DataComponentsOrdering, $orderMode: OrderingMode) {
+            query DataComponents($filters: FilterGroup, $search: String, $first: Int, $after: ID, $orderBy: DataComponentsOrdering, $orderMode: OrderingMode) {
                 dataComponents(filters: $filters, search: $search, first: $first, after: $after, orderBy: $orderBy, orderMode: $orderMode) {
                     edges {
                         node {
                             """
-            + (custom_attributes if custom_attributes is not None else self.properties)
+            + (
+                custom_attributes
+                if custom_attributes is not None
+                else (self.properties_with_files if with_files else self.properties)
+            )
             + """
                         }
                     }
@@ -212,10 +335,33 @@ class DataComponent:
                 "orderMode": order_mode,
             },
         )
-        # TODO: get_all ?
-        return self.opencti.process_multiple(
-            result["data"]["dataComponents"], with_pagination
-        )
+        if get_all:
+            final_data = []
+            data = self.opencti.process_multiple(result["data"]["dataComponents"])
+            final_data = final_data + data
+            while result["data"]["dataComponents"]["pageInfo"]["hasNextPage"]:
+                after = result["data"]["dataComponents"]["pageInfo"]["endCursor"]
+                self.opencti.app_logger.info(
+                    "Listing Data-Components", {"after": after}
+                )
+                result = self.opencti.query(
+                    query,
+                    {
+                        "filters": filters,
+                        "search": search,
+                        "first": first,
+                        "after": after,
+                        "orderBy": order_by,
+                        "orderMode": order_mode,
+                    },
+                )
+                data = self.opencti.process_multiple(result["data"]["dataComponents"])
+                final_data = final_data + data
+            return final_data
+        else:
+            return self.opencti.process_multiple(
+                result["data"]["dataComponents"], with_pagination
+            )
 
     """
         Read a Data-Component object
@@ -229,8 +375,9 @@ class DataComponent:
         id = kwargs.get("id", None)
         filters = kwargs.get("filters", None)
         custom_attributes = kwargs.get("customAttributes", None)
+        with_files = kwargs.get("withFiles", False)
         if id is not None:
-            self.opencti.log("info", "Reading Data-Component {" + id + "}.")
+            self.opencti.app_logger.info("Reading Data-Component", {"id": id})
             query = (
                 """
                 query DataComponent($id: String!) {
@@ -239,7 +386,7 @@ class DataComponent:
                 + (
                     custom_attributes
                     if custom_attributes is not None
-                    else self.properties
+                    else (self.properties_with_files if with_files else self.properties)
                 )
                 + """
                     }
@@ -255,8 +402,8 @@ class DataComponent:
             else:
                 return None
         else:
-            self.opencti.log(
-                "error", "[opencti_data_component] Missing parameters: id or filters"
+            self.opencti.app_logger.error(
+                "[opencti_data_component] Missing parameters: id or filters"
             )
             return None
 
@@ -279,16 +426,19 @@ class DataComponent:
         created = kwargs.get("created", None)
         modified = kwargs.get("modified", None)
         name = kwargs.get("name", None)
-        description = kwargs.get("description", "")
+        description = kwargs.get("description", None)
         dataSource = kwargs.get("dataSource", None)
         aliases = kwargs.get("aliases", None)
         x_opencti_stix_ids = kwargs.get("x_opencti_stix_ids", None)
         granted_refs = kwargs.get("objectOrganization", None)
+        x_opencti_workflow_id = kwargs.get("x_opencti_workflow_id", None)
         update = kwargs.get("update", False)
 
-        if name is not None and description is not None:
-            self.opencti.log("info", "Creating Data Component {" + name + "}.")
-            self.opencti.log("info", "Creating Data Component {" + str(kwargs) + "}.")
+        if name is not None:
+            self.opencti.app_logger.info("Creating Data Component", {"name": name})
+            self.opencti.app_logger.info(
+                "Creating Data Component", {"data": str(kwargs)}
+            )
             query = """
                 mutation DataComponentAdd($input: DataComponentAddInput!) {
                     dataComponentAdd(input: $input) {
@@ -319,6 +469,7 @@ class DataComponent:
                         "aliases": aliases,
                         "dataSource": dataSource,
                         "x_opencti_stix_ids": x_opencti_stix_ids,
+                        "x_opencti_workflow_id": x_opencti_workflow_id,
                         "update": update,
                     }
                 },
@@ -327,9 +478,8 @@ class DataComponent:
                 result["data"]["dataComponentAdd"]
             )
         else:
-            self.opencti.log(
-                "error",
-                "[opencti_data_component] Missing parameters: name and description",
+            self.opencti.app_logger.error(
+                "[opencti_data_component] Missing parameters: name and description"
             )
 
     """
@@ -359,56 +509,73 @@ class DataComponent:
 
             # Search in extensions
             if "x_opencti_stix_ids" not in stix_object:
-                stix_object[
-                    "x_opencti_stix_ids"
-                ] = self.opencti.get_attribute_in_extension("stix_ids", stix_object)
-            if "granted_refs" not in stix_object:
-                stix_object["granted_refs"] = self.opencti.get_attribute_in_extension(
-                    "granted_refs", stix_object
+                stix_object["x_opencti_stix_ids"] = (
+                    self.opencti.get_attribute_in_extension("stix_ids", stix_object)
+                )
+            if "x_opencti_granted_refs" not in stix_object:
+                stix_object["x_opencti_granted_refs"] = (
+                    self.opencti.get_attribute_in_extension("granted_refs", stix_object)
+                )
+            if "x_opencti_workflow_id" not in stix_object:
+                stix_object["x_opencti_workflow_id"] = (
+                    self.opencti.get_attribute_in_extension("workflow_id", stix_object)
                 )
 
             return self.opencti.data_component.create(
                 stix_id=stix_object["id"],
-                createdBy=extras["created_by_id"]
-                if "created_by_id" in extras
-                else None,
-                objectMarking=extras["object_marking_ids"]
-                if "object_marking_ids" in extras
-                else None,
-                objectLabel=extras["object_label_ids"]
-                if "object_label_ids" in extras
-                else [],
-                externalReferences=extras["external_references_ids"]
-                if "external_references_ids" in extras
-                else [],
+                createdBy=(
+                    extras["created_by_id"] if "created_by_id" in extras else None
+                ),
+                objectMarking=(
+                    extras["object_marking_ids"]
+                    if "object_marking_ids" in extras
+                    else None
+                ),
+                objectLabel=(
+                    extras["object_label_ids"] if "object_label_ids" in extras else None
+                ),
+                externalReferences=(
+                    extras["external_references_ids"]
+                    if "external_references_ids" in extras
+                    else None
+                ),
                 revoked=stix_object["revoked"] if "revoked" in stix_object else None,
-                confidence=stix_object["confidence"]
-                if "confidence" in stix_object
-                else None,
+                confidence=(
+                    stix_object["confidence"] if "confidence" in stix_object else None
+                ),
                 lang=stix_object["lang"] if "lang" in stix_object else None,
                 created=stix_object["created"] if "created" in stix_object else None,
                 modified=stix_object["modified"] if "modified" in stix_object else None,
                 name=stix_object["name"],
-                description=self.opencti.stix2.convert_markdown(
-                    stix_object["description"]
-                )
-                if "description" in stix_object
-                else "",
+                description=(
+                    self.opencti.stix2.convert_markdown(stix_object["description"])
+                    if "description" in stix_object
+                    else None
+                ),
                 aliases=self.opencti.stix2.pick_aliases(stix_object),
-                dataSource=stix_object["dataSource"]
-                if "dataSource" in stix_object
-                else None,
-                x_opencti_stix_ids=stix_object["x_opencti_stix_ids"]
-                if "x_opencti_stix_ids" in stix_object
-                else None,
-                objectOrganization=stix_object["granted_refs"]
-                if "granted_refs" in stix_object
-                else None,
+                dataSource=(
+                    stix_object["dataSource"] if "dataSource" in stix_object else None
+                ),
+                x_opencti_stix_ids=(
+                    stix_object["x_opencti_stix_ids"]
+                    if "x_opencti_stix_ids" in stix_object
+                    else None
+                ),
+                objectOrganization=(
+                    stix_object["x_opencti_granted_refs"]
+                    if "x_opencti_granted_refs" in stix_object
+                    else None
+                ),
+                x_opencti_workflow_id=(
+                    stix_object["x_opencti_workflow_id"]
+                    if "x_opencti_workflow_id" in stix_object
+                    else None
+                ),
                 update=update,
             )
         else:
-            self.opencti.log(
-                "error", "[opencti_data_source] Missing parameters: stixObject"
+            self.opencti.app_logger.error(
+                "[opencti_data_source] Missing parameters: stixObject"
             )
 
     def process_multiple_fields(self, data):
