@@ -9,6 +9,14 @@ from stix2.canonicalization.Canonicalize import canonicalize
 
 
 class ExternalReference:
+    """Main ExternalReference class for OpenCTI
+
+    Manages external references and citations in the OpenCTI platform.
+
+    :param opencti: instance of :py:class:`~pycti.api.opencti_api_client.OpenCTIApiClient`
+    :param file: file handling configuration
+    """
+
     def __init__(self, opencti, file):
         self.opencti = opencti
         self.file = file
