@@ -24,13 +24,27 @@ class Indicator:
 
     @staticmethod
     def generate_id(pattern):
-        data = {"pattern": pattern}
+        """Generate a STIX ID for an Indicator.
+
+        :param pattern: The STIX pattern
+        :type pattern: str
+        :return: STIX ID for the indicator
+        :rtype: str
+        """
+        data = {"pattern": pattern.strip()}
         data = canonicalize(data, utf8=False)
         id = str(uuid.uuid5(uuid.UUID("00abedb4-aa42-466c-9c01-fed23315a9b7"), data))
         return "indicator--" + id
 
     @staticmethod
     def generate_id_from_data(data):
+        """Generate a STIX ID from indicator data.
+
+        :param data: Dictionary containing 'pattern' key
+        :type data: dict
+        :return: STIX ID for the indicator
+        :rtype: str
+        """
         return Indicator.generate_id(data["pattern"])
 
     def list(self, **kwargs):
@@ -301,6 +315,43 @@ class Indicator:
                 "name or pattern or pattern_type or x_opencti_main_observable_type"
             )
 
+    def update_field(self, **kwargs):
+        """Update an Indicator object field.
+
+        :param id: the Indicator id
+        :param input: the input of the field
+        :return: Updated indicator object
+        :rtype: dict or None
+        """
+        id = kwargs.get("id", None)
+        input = kwargs.get("input", None)
+        if id is not None and input is not None:
+            self.opencti.app_logger.info("Updating Indicator", {"id": id})
+            query = """
+                        mutation IndicatorFieldPatch($id: ID!, $input: [EditInput!]!) {
+                            indicatorFieldPatch(id: $id, input: $input) {
+                                id
+                                standard_id
+                                entity_type
+                            }
+                        }
+                    """
+            result = self.opencti.query(
+                query,
+                {
+                    "id": id,
+                    "input": input,
+                },
+            )
+            return self.opencti.process_multiple_fields(
+                result["data"]["indicatorFieldPatch"]
+            )
+        else:
+            self.opencti.app_logger.error(
+                "[opencti_stix_domain_object] Cant update indicator field, missing parameters: id and input"
+            )
+            return None
+
     def add_stix_cyber_observable(self, **kwargs):
         """
         Add a Stix-Cyber-Observable object to Indicator object (based-on)
@@ -408,6 +459,12 @@ class Indicator:
                 stix_object["x_opencti_workflow_id"] = (
                     self.opencti.get_attribute_in_extension("workflow_id", stix_object)
                 )
+            if "x_mitre_platforms" not in stix_object:
+                stix_object["x_mitre_platforms"] = (
+                    self.opencti.get_attribute_in_mitre_extension(
+                        "platforms", stix_object
+                    )
+                )
 
             return self.create(
                 stix_id=stix_object["id"],
