@@ -5,8 +5,6 @@ import uuid
 
 from stix2.canonicalization.Canonicalize import canonicalize
 
-from pycti.entities import LOGGER
-
 
 class Infrastructure:
     """Main Infrastructure class for OpenCTI
@@ -24,6 +22,14 @@ class Infrastructure:
             spec_version
             created_at
             updated_at
+            status {
+                id
+                template {
+                  id
+                  name
+                  color
+                }
+            }
             createdBy {
                 ... on Identity {
                     id
@@ -40,13 +46,9 @@ class Infrastructure:
                     created
                     modified
                     objectLabel {
-                        edges {
-                            node {
-                                id
-                                value
-                                color
-                            }
-                        }
+                        id
+                        value
+                        color
                     }
                 }
                 ... on Organization {
@@ -58,29 +60,129 @@ class Infrastructure:
                     x_opencti_lastname
                 }
             }
+            objectOrganization {
+                id
+                standard_id
+                name
+            }
             objectMarking {
+                id
+                standard_id
+                entity_type
+                definition_type
+                definition
+                created
+                modified
+                x_opencti_order
+                x_opencti_color
+            }
+            objectLabel {
+                id
+                value
+                color
+            }
+            externalReferences {
                 edges {
                     node {
                         id
                         standard_id
                         entity_type
-                        definition_type
-                        definition
+                        source_name
+                        description
+                        url
+                        hash
+                        external_id
                         created
                         modified
-                        x_opencti_order
-                        x_opencti_color
                     }
                 }
             }
-            objectLabel {
-                edges {
-                    node {
+            revoked
+            confidence
+            created
+            modified
+            name
+            description
+            infrastructure_types
+            first_seen
+            last_seen
+            killChainPhases {
+              id
+              standard_id
+              entity_type
+              kill_chain_name
+              phase_name
+              x_opencti_order
+              created
+              modified
+            }
+        """
+        self.properties_with_files = """
+            id
+            standard_id
+            entity_type
+            parent_types
+            spec_version
+            created_at
+            updated_at
+            status {
+                id
+                template {
+                  id
+                  name
+                  color
+                }
+            }
+            createdBy {
+                ... on Identity {
+                    id
+                    standard_id
+                    entity_type
+                    parent_types
+                    spec_version
+                    identity_class
+                    name
+                    description
+                    roles
+                    contact_information
+                    x_opencti_aliases
+                    created
+                    modified
+                    objectLabel {
                         id
                         value
                         color
                     }
                 }
+                ... on Organization {
+                    x_opencti_organization_type
+                    x_opencti_reliability
+                }
+                ... on Individual {
+                    x_opencti_firstname
+                    x_opencti_lastname
+                }
+            }
+            objectOrganization {
+                id
+                standard_id
+                name
+            }
+            objectMarking {
+                id
+                standard_id
+                entity_type
+                definition_type
+                definition
+                created
+                modified
+                x_opencti_order
+                x_opencti_color
+            }
+            objectLabel {
+                id
+                value
+                color
             }
             externalReferences {
                 edges {
@@ -121,18 +223,14 @@ class Infrastructure:
             first_seen
             last_seen
             killChainPhases {
-                edges {
-                    node {
-                        id
-                        standard_id
-                        entity_type
-                        kill_chain_name
-                        phase_name
-                        x_opencti_order
-                        created
-                        modified
-                    }
-                }
+              id
+              standard_id
+              entity_type
+              kill_chain_name
+              phase_name
+              x_opencti_order
+              created
+              modified
             }
             importFiles {
                 edges {
@@ -157,6 +255,10 @@ class Infrastructure:
         id = str(uuid.uuid5(uuid.UUID("00abedb4-aa42-466c-9c01-fed23315a9b7"), data))
         return "infrastructure--" + id
 
+    @staticmethod
+    def generate_id_from_data(data):
+        return Infrastructure.generate_id(data["name"])
+
     def list(self, **kwargs):
         """List Infrastructure objects
 
@@ -183,18 +285,23 @@ class Infrastructure:
         custom_attributes = kwargs.get("customAttributes", None)
         get_all = kwargs.get("getAll", False)
         with_pagination = kwargs.get("withPagination", False)
-        if get_all:
-            first = 500
+        with_files = kwargs.get("withFiles", False)
 
-        LOGGER.info("Listing Infrastructures with filters %s.", json.dumps(filters))
+        self.opencti.app_logger.info(
+            "Listing Infrastructures with filters", {"filters": json.dumps(filters)}
+        )
         query = (
             """
-            query Infrastructures($filters: [InfrastructuresFiltering], $search: String, $first: Int, $after: ID, $orderBy: InfrastructuresOrdering, $orderMode: OrderingMode) {
+            query Infrastructures($filters: FilterGroup, $search: String, $first: Int, $after: ID, $orderBy: InfrastructuresOrdering, $orderMode: OrderingMode) {
                 infrastructures(filters: $filters, search: $search, first: $first, after: $after, orderBy: $orderBy, orderMode: $orderMode) {
                     edges {
                         node {
                             """
-            + (custom_attributes if custom_attributes is not None else self.properties)
+            + (
+                custom_attributes
+                if custom_attributes is not None
+                else (self.properties_with_files if with_files else self.properties)
+            )
             + """
                         }
                     }
@@ -227,7 +334,9 @@ class Infrastructure:
             final_data = final_data + data
             while result["data"]["infrastructures"]["pageInfo"]["hasNextPage"]:
                 after = result["data"]["infrastructures"]["pageInfo"]["endCursor"]
-                LOGGER.info("Listing Infrastructures after " + after)
+                self.opencti.app_logger.info(
+                    "Listing Infrastructures", {"after": after}
+                )
                 result = self.opencti.query(
                     query,
                     {
@@ -257,15 +366,16 @@ class Infrastructure:
 
         Note: either `id` or `filters` is required.
 
-        :param str id: the id of the Threat-Actor
+        :param str id: the id of the Threat-Actor-Group
         :param list filters: the filters to apply if no id provided
         """
 
         id = kwargs.get("id", None)
         filters = kwargs.get("filters", None)
         custom_attributes = kwargs.get("customAttributes", None)
+        with_files = kwargs.get("withFiles", False)
         if id is not None:
-            LOGGER.info("Reading Infrastructure {%s}.", id)
+            self.opencti.app_logger.info("Reading Infrastructure", {"id": id})
             query = (
                 """
                 query Infrastructure($id: String!) {
@@ -274,7 +384,7 @@ class Infrastructure:
                 + (
                     custom_attributes
                     if custom_attributes is not None
-                    else self.properties
+                    else (self.properties_with_files if with_files else self.properties)
                 )
                 + """
                     }
@@ -292,7 +402,9 @@ class Infrastructure:
             else:
                 return None
         else:
-            LOGGER.error("[opencti_infrastructure] Missing parameters: id or filters")
+            self.opencti.app_logger.error(
+                "[opencti_infrastructure] Missing parameters: id or filters"
+            )
             return None
 
     """
@@ -321,12 +433,14 @@ class Infrastructure:
         last_seen = kwargs.get("last_seen", None)
         kill_chain_phases = kwargs.get("killChainPhases", None)
         x_opencti_stix_ids = kwargs.get("x_opencti_stix_ids", None)
+        granted_refs = kwargs.get("objectOrganization", None)
+        x_opencti_workflow_id = kwargs.get("x_opencti_workflow_id", None)
         update = kwargs.get("update", False)
 
         if name is not None:
-            LOGGER.info("Creating Infrastructure {%s}.", name)
+            self.opencti.app_logger.info("Creating Infrastructure", {"name": name})
             query = """
-                mutation InfrastructureAdd($input: InfrastructureAddInput) {
+                mutation InfrastructureAdd($input: InfrastructureAddInput!) {
                     infrastructureAdd(input: $input) {
                         id
                         standard_id
@@ -343,6 +457,7 @@ class Infrastructure:
                         "createdBy": created_by,
                         "objectMarking": object_marking,
                         "objectLabel": object_label,
+                        "objectOrganization": granted_refs,
                         "externalReferences": external_references,
                         "revoked": revoked,
                         "confidence": confidence,
@@ -357,6 +472,7 @@ class Infrastructure:
                         "last_seen": last_seen,
                         "killChainPhases": kill_chain_phases,
                         "x_opencti_stix_ids": x_opencti_stix_ids,
+                        "x_opencti_workflow_id": x_opencti_workflow_id,
                         "update": update,
                     }
                 },
@@ -365,7 +481,7 @@ class Infrastructure:
                 result["data"]["infrastructureAdd"]
             )
         else:
-            LOGGER.error(
+            self.opencti.app_logger.error(
                 "[opencti_infrastructure] Missing parameters: "
                 "name and infrastructure_pattern and main_observable_type"
             )
@@ -381,58 +497,87 @@ class Infrastructure:
         stix_object = kwargs.get("stixObject", None)
         extras = kwargs.get("extras", {})
         update = kwargs.get("update", False)
-
-        # Search in extensions
-        if "x_opencti_stix_ids" not in stix_object:
-            stix_object["x_opencti_stix_ids"] = self.opencti.get_attribute_in_extension(
-                "stix_ids", stix_object
-            )
-
         if stix_object is not None:
+            # Search in extensions
+            if "x_opencti_stix_ids" not in stix_object:
+                stix_object["x_opencti_stix_ids"] = (
+                    self.opencti.get_attribute_in_extension("stix_ids", stix_object)
+                )
+            if "x_opencti_granted_refs" not in stix_object:
+                stix_object["x_opencti_granted_refs"] = (
+                    self.opencti.get_attribute_in_extension("granted_refs", stix_object)
+                )
+            if "x_opencti_workflow_id" not in stix_object:
+                stix_object["x_opencti_workflow_id"] = (
+                    self.opencti.get_attribute_in_extension("workflow_id", stix_object)
+                )
+
             return self.create(
                 stix_id=stix_object["id"],
-                createdBy=extras["created_by_id"]
-                if "created_by_id" in extras
-                else None,
-                objectMarking=extras["object_marking_ids"]
-                if "object_marking_ids" in extras
-                else None,
-                objectLabel=extras["object_label_ids"]
-                if "object_label_ids" in extras
-                else [],
-                externalReferences=extras["external_references_ids"]
-                if "external_references_ids" in extras
-                else [],
+                createdBy=(
+                    extras["created_by_id"] if "created_by_id" in extras else None
+                ),
+                objectMarking=(
+                    extras["object_marking_ids"]
+                    if "object_marking_ids" in extras
+                    else None
+                ),
+                objectLabel=(
+                    extras["object_label_ids"] if "object_label_ids" in extras else None
+                ),
+                externalReferences=(
+                    extras["external_references_ids"]
+                    if "external_references_ids" in extras
+                    else None
+                ),
                 revoked=stix_object["revoked"] if "revoked" in stix_object else None,
-                confidence=stix_object["confidence"]
-                if "confidence" in stix_object
-                else None,
+                confidence=(
+                    stix_object["confidence"] if "confidence" in stix_object else None
+                ),
                 lang=stix_object["lang"] if "lang" in stix_object else None,
                 created=stix_object["created"] if "created" in stix_object else None,
                 modified=stix_object["modified"] if "modified" in stix_object else None,
                 name=stix_object["name"],
-                description=self.opencti.stix2.convert_markdown(
-                    stix_object["description"]
-                )
-                if "description" in stix_object
-                else "",
+                description=(
+                    self.opencti.stix2.convert_markdown(stix_object["description"])
+                    if "description" in stix_object
+                    else None
+                ),
                 aliases=self.opencti.stix2.pick_aliases(stix_object),
-                infrastructure_types=stix_object["infrastructure_types"]
-                if "infrastructure_types" in stix_object
-                else None,
-                first_seen=stix_object["first_seen"]
-                if "first_seen" in stix_object
-                else None,
-                last_seen=stix_object["last_seen"]
-                if "last_seen" in stix_object
-                else None,
-                killChainPhases=extras["kill_chain_phases_ids"]
-                if "kill_chain_phases_ids" in extras
-                else None,
-                x_opencti_stix_ids=stix_object["x_opencti_stix_ids"]
-                if "x_opencti_stix_ids" in stix_object
-                else None,
+                infrastructure_types=(
+                    stix_object["infrastructure_types"]
+                    if "infrastructure_types" in stix_object
+                    else None
+                ),
+                first_seen=(
+                    stix_object["first_seen"] if "first_seen" in stix_object else None
+                ),
+                last_seen=(
+                    stix_object["last_seen"] if "last_seen" in stix_object else None
+                ),
+                killChainPhases=(
+                    extras["kill_chain_phases_ids"]
+                    if "kill_chain_phases_ids" in extras
+                    else None
+                ),
+                x_opencti_stix_ids=(
+                    stix_object["x_opencti_stix_ids"]
+                    if "x_opencti_stix_ids" in stix_object
+                    else None
+                ),
+                objectOrganization=(
+                    stix_object["x_opencti_granted_refs"]
+                    if "x_opencti_granted_refs" in stix_object
+                    else None
+                ),
+                x_opencti_workflow_id=(
+                    stix_object["x_opencti_workflow_id"]
+                    if "x_opencti_workflow_id" in stix_object
+                    else None
+                ),
                 update=update,
             )
         else:
-            LOGGER.error("[opencti_attack_pattern] Missing parameters: stixObject")
+            self.opencti.app_logger.error(
+                "[opencti_infrastructure] Missing parameters: stixObject"
+            )
