@@ -7,6 +7,13 @@ from stix2.canonicalization.Canonicalize import canonicalize
 
 
 class Malware:
+    """Main Malware class for OpenCTI
+
+    Manages malware families and variants in the OpenCTI platform.
+
+    :param opencti: instance of :py:class:`~pycti.api.opencti_api_client.OpenCTIApiClient`
+    """
+
     def __init__(self, opencti):
         self.opencti = opencti
         self.properties = """
@@ -260,6 +267,13 @@ class Malware:
 
     @staticmethod
     def generate_id(name):
+        """Generate a STIX ID for a Malware.
+
+        :param name: The name of the malware
+        :type name: str
+        :return: STIX ID for the malware
+        :rtype: str
+        """
         name = name.lower().strip()
         data = {"name": name}
         data = canonicalize(data, utf8=False)
@@ -268,19 +282,31 @@ class Malware:
 
     @staticmethod
     def generate_id_from_data(data):
+        """Generate a STIX ID from malware data.
+
+        :param data: Dictionary containing 'name' key
+        :type data: dict
+        :return: STIX ID for the malware
+        :rtype: str
+        """
         return Malware.generate_id(data["name"])
 
-    """
-        List Malware objects
+    def list(self, **kwargs):
+        """List Malware objects.
 
         :param filters: the filters to apply
         :param search: the search keyword
         :param first: return the first n rows from the after ID (or the beginning if not set)
         :param after: ID of the first row for pagination
-        :return List of Malware objects
-    """
-
-    def list(self, **kwargs):
+        :param orderBy: field to order results by
+        :param orderMode: ordering mode (asc/desc)
+        :param customAttributes: custom attributes to return
+        :param getAll: whether to retrieve all results
+        :param withPagination: whether to include pagination info
+        :param withFiles: whether to include files
+        :return: List of Malware objects
+        :rtype: list
+        """
         filters = kwargs.get("filters", None)
         search = kwargs.get("search", None)
         first = kwargs.get("first", 500)
@@ -359,15 +385,16 @@ class Malware:
                 result["data"]["malwares"], with_pagination
             )
 
-    """
-        Read a Malware object
+    def read(self, **kwargs):
+        """Read a Malware object.
 
         :param id: the id of the Malware
         :param filters: the filters to apply if no id provided
-        :return Malware object
-    """
-
-    def read(self, **kwargs):
+        :param customAttributes: custom attributes to return
+        :param withFiles: whether to include files
+        :return: Malware object
+        :rtype: dict or None
+        """
         id = kwargs.get("id", None)
         filters = kwargs.get("filters", None)
         custom_attributes = kwargs.get("customAttributes", None)
@@ -403,14 +430,29 @@ class Malware:
             )
             return None
 
-    """
-        Create a Malware object
+    def create(self, **kwargs):
+        """Create a Malware object.
 
         :param name: the name of the Malware
-        :return Malware object
-    """
-
-    def create(self, **kwargs):
+        :param description: description of the malware
+        :param aliases: list of aliases
+        :param malware_types: types of malware
+        :param is_family: whether this is a malware family
+        :param first_seen: first seen date
+        :param last_seen: last seen date
+        :param architecture_execution_envs: execution environments
+        :param implementation_languages: implementation languages
+        :param capabilities: malware capabilities
+        :param killChainPhases: kill chain phases
+        :param samples: malware samples
+        :param createdBy: creator identity
+        :param objectMarking: marking definitions
+        :param objectLabel: labels
+        :param externalReferences: external references
+        :param update: whether to update existing malware
+        :return: Malware object
+        :rtype: dict or None
+        """
         stix_id = kwargs.get("stix_id", None)
         created_by = kwargs.get("createdBy", None)
         object_marking = kwargs.get("objectMarking", None)
