@@ -5,10 +5,15 @@ import uuid
 
 from stix2.canonicalization.Canonicalize import canonicalize
 
-from pycti.entities import LOGGER
-
 
 class MarkingDefinition:
+    """Main MarkingDefinition class for OpenCTI
+
+    Manages marking definitions (TLP, statements) in the OpenCTI platform.
+
+    :param opencti: instance of :py:class:`~pycti.api.opencti_api_client.OpenCTIApiClient`
+    """
+
     def __init__(self, opencti):
         self.opencti = opencti
         self.properties = """
@@ -27,12 +32,31 @@ class MarkingDefinition:
         """
 
     @staticmethod
-    def generate_id(definition, definition_type):
-        data = {"definition": definition, "definition_type": definition_type}
+    def generate_id(definition_type, definition):
+        # Handle static IDs from OpenCTI
+        if definition_type == "TLP":
+            if definition == "TLP:CLEAR" or definition == "TLP:WHITE":
+                return "marking-definition--613f2e26-407d-48c7-9eca-b8e91df99dc9"
+            if definition == "TLP:GREEN":
+                return "marking-definition--34098fce-860f-48ae-8e50-ebd3cc5e41da"
+            if definition == "TLP:AMBER":
+                return "marking-definition--f88d31f6-486f-44da-b317-01333bde0b82"
+            if definition == "TLP:AMBER+STRICT":
+                return "marking-definition--826578e1-40ad-459f-bc73-ede076f81f37"
+            if definition == "TLP:RED":
+                return "marking-definition--5e57c739-391a-4eb3-b6be-7d15ca92d5ed"
+        # Generate IDs
+        data = {"definition_type": definition_type, "definition": definition}
         data = canonicalize(data, utf8=False)
         id = str(uuid.uuid5(uuid.UUID("00abedb4-aa42-466c-9c01-fed23315a9b7"), data))
         return "marking-definition--" + id
 
+    @staticmethod
+    def generate_id_from_data(data):
+        return MarkingDefinition.generate_id(
+            data["definition_type"], data["definition"]
+        )
+
     """
         List Marking-Definition objects
 
@@ -49,15 +73,14 @@ class MarkingDefinition:
         order_by = kwargs.get("orderBy", None)
         order_mode = kwargs.get("orderMode", None)
         custom_attributes = kwargs.get("customAttributes", None)
-        get_all = kwargs.get("getAll", False)
         with_pagination = kwargs.get("withPagination", False)
-        if get_all:
-            first = 500
 
-        LOGGER.info("Listing Marking-Definitions with filters %s.", json.dumps(filters))
+        self.opencti.app_logger.info(
+            "Listing Marking-Definitions with filters", {"filters": json.dumps(filters)}
+        )
         query = (
             """
-            query MarkingDefinitions($filters: [MarkingDefinitionsFiltering], $first: Int, $after: ID, $orderBy: MarkingDefinitionsOrdering, $orderMode: OrderingMode) {
+            query MarkingDefinitions($filters: FilterGroup, $first: Int, $after: ID, $orderBy: MarkingDefinitionsOrdering, $orderMode: OrderingMode) {
                 markingDefinitions(filters: $filters, first: $first, after: $after, orderBy: $orderBy, orderMode: $orderMode) {
                     edges {
                         node {
@@ -103,7 +126,7 @@ class MarkingDefinition:
         id = kwargs.get("id", None)
         filters = kwargs.get("filters", None)
         if id is not None:
-            LOGGER.info("Reading Marking-Definition {%s}.", id)
+            self.opencti.app_logger.info("Reading Marking-Definition", {"id": id})
             query = (
                 """
                 query MarkingDefinition($id: String!) {
@@ -126,7 +149,7 @@ class MarkingDefinition:
             else:
                 return None
         else:
-            LOGGER.error(
+            self.opencti.app_logger.error(
                 "[opencti_marking_definition] Missing parameters: id or filters"
             )
             return None
@@ -153,7 +176,7 @@ class MarkingDefinition:
         if definition is not None and definition_type is not None:
             query = (
                 """
-                mutation MarkingDefinitionAdd($input: MarkingDefinitionAddInput) {
+                mutation MarkingDefinitionAdd($input: MarkingDefinitionAddInput!) {
                     markingDefinitionAdd(input: $input) {
                         """
                 + self.properties
@@ -182,7 +205,7 @@ class MarkingDefinition:
                 result["data"]["markingDefinitionAdd"]
             )
         else:
-            LOGGER.error(
+            self.opencti.app_logger.error(
                 "[opencti_marking_definition] Missing parameters: definition and definition_type",
             )
 
@@ -198,7 +221,7 @@ class MarkingDefinition:
         id = kwargs.get("id", None)
         input = kwargs.get("input", None)
         if id is not None and input is not None:
-            LOGGER.info("Updating Marking Definition {%s}.", id)
+            self.opencti.app_logger.info("Updating Marking Definition", {"id": id})
             query = """
                     mutation MarkingDefinitionEdit($id: ID!, $input: [EditInput]!) {
                         markingDefinitionEdit(id: $id) {
@@ -221,7 +244,7 @@ class MarkingDefinition:
                 result["data"]["markingDefinitionEdit"]["fieldPatch"]
             )
         else:
-            LOGGER.error(
+            self.opencti.app_logger.error(
                 "[opencti_marking_definition] Missing parameters: id and key and value"
             )
             return None
@@ -236,25 +259,50 @@ class MarkingDefinition:
     def import_from_stix2(self, **kwargs):
         stix_object = kwargs.get("stixObject", None)
         update = kwargs.get("update", False)
-
         if stix_object is not None:
-            definition = None
-            definition_type = stix_object["definition_type"]
-            if stix_object["definition_type"] == "tlp":
-                definition_type = definition_type.upper()
-                if "definition" in stix_object:
-                    definition = (
-                        definition_type + ":" + stix_object["definition"]["tlp"].upper()
-                    )
-                elif "name" in stix_object:
-                    definition = stix_object["name"]
+            if (
+                "x_opencti_definition_type" in stix_object
+                and "x_opencti_definition" in stix_object
+            ):
+                definition_type = stix_object["x_opencti_definition_type"]
+                definition = stix_object["x_opencti_definition"]
+            elif "definition_type" in stix_object:
+                definition_type = stix_object["definition_type"]
+                definition = None
+                if stix_object["definition_type"] == "tlp":
+                    definition_type = definition_type.upper()
+                    if "definition" in stix_object:
+                        definition = (
+                            definition_type
+                            + ":"
+                            + stix_object["definition"]["tlp"].upper()
+                        )
+                    elif "name" in stix_object:
+                        definition = stix_object["name"]
+                else:
+                    if "definition" in stix_object:
+                        if isinstance(stix_object["definition"], str):
+                            definition = stix_object["definition"]
+                        elif (
+                            isinstance(stix_object["definition"], dict)
+                            and stix_object["definition_type"]
+                            in stix_object["definition"]
+                        ):
+                            definition = stix_object["definition"][
+                                stix_object["definition_type"]
+                            ]
+                        else:
+                            definition = stix_object["name"]
+                    elif "name" in stix_object:
+                        definition = stix_object["name"]
+            elif "name" in stix_object:
+                if ":" in stix_object["name"]:
+                    definition_type = stix_object["name"].split(":")[0]
+                else:
+                    definition_type = "statement"
+                definition = stix_object["name"]
             else:
-                if "definition" in stix_object:
-                    definition = stix_object["definition"][
-                        stix_object["definition_type"]
-                    ]
-                elif "name" in stix_object:
-                    definition = stix_object["name"]
+                return None
 
             # Replace TLP:WHITE
             if definition == "TLP:WHITE":
@@ -266,17 +314,17 @@ class MarkingDefinition:
                 and self.opencti.get_attribute_in_extension("order", stix_object)
                 is not None
             ):
-                stix_object[
-                    "x_opencti_order"
-                ] = self.opencti.get_attribute_in_extension("order", stix_object)
+                stix_object["x_opencti_order"] = (
+                    self.opencti.get_attribute_in_extension("order", stix_object)
+                )
             if "x_opencti_color" not in stix_object:
-                stix_object[
-                    "x_opencti_color"
-                ] = self.opencti.get_attribute_in_extension("color", stix_object)
+                stix_object["x_opencti_color"] = (
+                    self.opencti.get_attribute_in_extension("color", stix_object)
+                )
             if "x_opencti_stix_ids" not in stix_object:
-                stix_object[
-                    "x_opencti_stix_ids"
-                ] = self.opencti.get_attribute_in_extension("stix_ids", stix_object)
+                stix_object["x_opencti_stix_ids"] = (
+                    self.opencti.get_attribute_in_extension("stix_ids", stix_object)
+                )
 
             return self.opencti.marking_definition.create(
                 stix_id=stix_object["id"],
@@ -284,24 +332,32 @@ class MarkingDefinition:
                 modified=stix_object["modified"] if "modified" in stix_object else None,
                 definition_type=definition_type,
                 definition=definition,
-                x_opencti_order=stix_object["x_opencti_order"]
-                if "x_opencti_order" in stix_object
-                else 0,
-                x_opencti_color=stix_object["x_opencti_color"]
-                if "x_opencti_color" in stix_object
-                else None,
-                x_opencti_stix_ids=stix_object["x_opencti_stix_ids"]
-                if "x_opencti_stix_ids" in stix_object
-                else None,
+                x_opencti_order=(
+                    stix_object["x_opencti_order"]
+                    if "x_opencti_order" in stix_object
+                    else 0
+                ),
+                x_opencti_color=(
+                    stix_object["x_opencti_color"]
+                    if "x_opencti_color" in stix_object
+                    else None
+                ),
+                x_opencti_stix_ids=(
+                    stix_object["x_opencti_stix_ids"]
+                    if "x_opencti_stix_ids" in stix_object
+                    else None
+                ),
                 update=update,
             )
         else:
-            LOGGER.error("[opencti_marking_definition] Missing parameters: stixObject")
+            self.opencti.app_logger.error(
+                "[opencti_marking_definition] Missing parameters: stixObject"
+            )
 
     def delete(self, **kwargs):
         id = kwargs.get("id", None)
         if id is not None:
-            LOGGER.info("Deleting Marking-Definition {%s}.", id)
+            self.opencti.app_logger.info("Deleting Marking-Definition", {"id": id})
             query = """
                  mutation MarkingDefinitionEdit($id: ID!) {
                      markingDefinitionEdit(id: $id) {
@@ -311,5 +367,7 @@ class MarkingDefinition:
              """
             self.opencti.query(query, {"id": id})
         else:
-            LOGGER.error("[opencti_marking_definition] Missing parameters: id")
+            self.opencti.app_logger.error(
+                "[opencti_marking_definition] Missing parameters: id"
+            )
             return None
