@@ -17,6 +17,15 @@ from .stix_cyber_observable.opencti_stix_cyber_observable_properties import (
 
 
 class StixCyberObservable(StixCyberObservableDeprecatedMixin):
+    """Main StixCyberObservable class for OpenCTI
+
+    Manages STIX cyber observables (indicators of compromise) in the OpenCTI platform.
+    Note: Deprecated methods are available through StixCyberObservableDeprecatedMixin.
+
+    :param opencti: instance of :py:class:`~pycti.api.opencti_api_client.OpenCTIApiClient`
+    :param file: file handling configuration
+    """
+
     def __init__(self, opencti, file):
 
         self.opencti = opencti
@@ -948,7 +957,7 @@ class StixCyberObservable(StixCyberObservableDeprecatedMixin):
                     ),
                 }
             elif type == "Windows-Registry-Value-Type":
-                input_variables["WindowsRegistryKeyValueType"] = {
+                input_variables["WindowsRegistryValueType"] = {
                     "name": (
                         observable_data["name"] if "name" in observable_data else None
                     ),
