@@ -2,6 +2,13 @@ import json
 
 
 class StixObjectOrStixRelationship:
+    """Main StixObjectOrStixRelationship class for OpenCTI
+
+    Manages generic STIX objects and relationships in the OpenCTI platform.
+
+    :param opencti: instance of :py:class:`~pycti.api.opencti_api_client.OpenCTIApiClient`
+    """
+
     def __init__(self, opencti):
         self.opencti = opencti
         self.properties = """
